@@ -11,12 +11,12 @@ logger.setLevel(logging.DEBUG)
 def main():
     parser = argparse.ArgumentParser()
     parser.add_argument("items", nargs="*", type=str)
-    parser.add_argument("-m", "--min", type=int, default=0)
-    parser.add_argument("-M", "--max", type=int, default=-1)
+    parser.add_argument("-m", "--min", type=int, default=0, help="Min number of selected items.")
+    parser.add_argument("-M", "--max", type=int, default=-1, help="Max number of selected items.")
     parser.add_argument("-r", "--retry", action="store_true")
     parser.add_argument("-d", "--debug", action="store_true")
-    parser.add_argument("-j", "--json", action="store_true")
-    parser.add_argument("-i", "--index", action="store_true")
+    parser.add_argument("-j", "--json", action="store_true", help="Output json str")
+    parser.add_argument("-i", "--index", action="store_true", help="Output item index")
     parser.add_argument("-p", "--prompt", type=str, default="Select: ")
     config = parser.parse_args()
 
